;; Generated package description from cperl-mode.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "cperl-mode" "33.0.0.0.20260828.0" "Perl code editing commands" '((emacs "26.1")) :commit "07c786f8618b2847f7951ed0de3ccb45377e2bf8" :authors '(("Ilya Zakharevich" . "ilyaz@cpan.org") ("Jonathan Rockway" . "jon@jrock.us")) :maintainer '(nil . "emacs-devel@gnu.org") :keywords '("languages") :url "https://elpa.gnu.org/packages/cperl-mode.html")
